# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.api_key_auth import ApiKeyAuth
from ...types.general_auth import GeneralAuth

Authdata = typing.Union[ApiKeyAuth, GeneralAuth]
